@@ -168,6 +168,18 @@ AUGMENTATION_CLS_PARAMS = (
                 "value": (10, 10, 10),
             },
         ],
+        [
+            A.ShiftScaleRotate,
+            {
+                "shift_limit_x": 0.3,
+                "shift_limit_y": 0.4,
+                "scale_limit": 0.2,
+                "rotate_limit": 70,
+                "interpolation": cv2.INTER_CUBIC,
+                "border_mode": cv2.BORDER_CONSTANT,
+                "value": (10, 10, 10),
+            },
+        ],
         [
             A.OpticalDistortion,
             {
@@ -500,14 +512,7 @@ def test_imgaug_augmentations_for_keypoints_serialization(
 
 @pytest.mark.parametrize(
     ["augmentation_cls", "params", "call_params"],
-    [
-        [A.RandomCropNearBBox, {"max_part_shift": 0.15}, {"cropping_bbox": [-59, 77, 177, 231]}],
-        [
-            A.FDA,
-            {"beta_limit": 0.3},
-            {"target_image": np.random.randint(low=0, high=256, size=(100, 100, 3), dtype=np.uint8)},
-        ],
-    ],
+    [[A.RandomCropNearBBox, {"max_part_shift": 0.15}, {"cropping_bbox": [-59, 77, 177, 231]}]],
 )
 @pytest.mark.parametrize("p", [0.5, 1])
 @pytest.mark.parametrize("seed", TEST_SEEDS)
