@@ -808,3 +808,16 @@ def test_hue_saturation_value_float_uint8_equal(hue, sat, val):
 
             _max = np.abs(res1.astype(np.int) - res2).max()
             assert _max <= 10, "Max value: {}".format(_max)
+
+
+def test_shift_scale_separate_shift_x_shift_y(image, mask):
+    aug = A.ShiftScaleRotate(shift_limit=(0.3, 0.3), shift_limit_y=(0.4, 0.4), scale_limit=0, rotate_limit=0, p=1)
+    data = aug(image=image, mask=mask)
+    expected_image = F.shift_scale_rotate(
+        image, angle=0, scale=1, dx=0.3, dy=0.4, interpolation=cv2.INTER_LINEAR, border_mode=cv2.BORDER_REFLECT_101
+    )
+    expected_mask = F.shift_scale_rotate(
+        mask, angle=0, scale=1, dx=0.3, dy=0.4, interpolation=cv2.INTER_NEAREST, border_mode=cv2.BORDER_REFLECT_101
+    )
+    assert np.array_equal(data["image"], expected_image)
+    assert np.array_equal(data["mask"], expected_mask)
